@@ -118,8 +118,7 @@ panel.factorvectors <- function(x, y, ssaobj, ..., ref = FALSE) {
     warning(sprintf("Elementary matrices are not F-orthogonal (max F-cor is %s). Contributions can be irrelevant",
                     format(isfcor, digits = 3)))
 
-  total <- wnorm(x)^2
-  round(100*x$sigma[idx]^2 / total, digits = 2)
+  round(100 * contributions(x, idx), digits = 2)
 }
 
 .plot.ssa.vectors <- function(x, ...)
@@ -443,7 +442,7 @@ plot.fdimpars.1d <- function(x, ...) {
             dots))
 }
 
-plot.fdimpars.2d <- function(x, ...) {
+plot.fdimpars.nd <- function(x, ...) {
   dots <- list(...)
 
   # Provide convenient defaults
@@ -454,9 +453,14 @@ plot.fdimpars.2d <- function(x, ...) {
                     aspect = 1,
                     pch = 19)
 
+  if (length(names(x)) == 0 || any(names(x) == "")) {
+    names(x) <- paste("x", seq_along(x), sep = "_")
+  }
+
+
   data <- list()
-  data$root <- c(x[[1]]$roots, x[[2]]$roots)
-  data$ind <- rep(c("lambda", "mu"), each = length(x[[1]]$roots))
+  data$root <- do.call(c, lapply(x, function(e) e$roots))
+  data$ind <- rep(names(x), each = length(x[[1]]$roots))
 
   do.call("xyplot",
           c(list(Im(root) ~ Re(root) | ind,
